@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@ import functools
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
+import warnings
 
 from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
@@ -38,6 +39,7 @@ from google.cloud.osconfig_v1alpha.types import config_common
 from google.cloud.osconfig_v1alpha.types import instance_os_policies_compliance
 from google.cloud.osconfig_v1alpha.types import inventory
 from google.cloud.osconfig_v1alpha.types import os_policy
+from google.cloud.osconfig_v1alpha.types import os_policy_assignment_reports
 from google.cloud.osconfig_v1alpha.types import os_policy_assignments
 from google.cloud.osconfig_v1alpha.types import vulnerability
 from google.protobuf import empty_pb2  # type: ignore
@@ -68,6 +70,12 @@ class OsConfigZonalServiceAsyncClient:
     parse_instance_os_policies_compliance_path = staticmethod(
         OsConfigZonalServiceClient.parse_instance_os_policies_compliance_path
     )
+    instance_os_policy_assignment_path = staticmethod(
+        OsConfigZonalServiceClient.instance_os_policy_assignment_path
+    )
+    parse_instance_os_policy_assignment_path = staticmethod(
+        OsConfigZonalServiceClient.parse_instance_os_policy_assignment_path
+    )
     inventory_path = staticmethod(OsConfigZonalServiceClient.inventory_path)
     parse_inventory_path = staticmethod(OsConfigZonalServiceClient.parse_inventory_path)
     os_policy_assignment_path = staticmethod(
@@ -76,6 +84,12 @@ class OsConfigZonalServiceAsyncClient:
     parse_os_policy_assignment_path = staticmethod(
         OsConfigZonalServiceClient.parse_os_policy_assignment_path
     )
+    os_policy_assignment_report_path = staticmethod(
+        OsConfigZonalServiceClient.os_policy_assignment_report_path
+    )
+    parse_os_policy_assignment_report_path = staticmethod(
+        OsConfigZonalServiceClient.parse_os_policy_assignment_report_path
+    )
     vulnerability_report_path = staticmethod(
         OsConfigZonalServiceClient.vulnerability_report_path
     )
@@ -263,7 +277,7 @@ class OsConfigZonalServiceAsyncClient:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -292,6 +306,8 @@ class OsConfigZonalServiceAsyncClient:
                 print("Waiting for operation to complete...")
 
                 response = operation.result()
+
+                # Handle the response
                 print(response)
 
         Args:
@@ -426,7 +442,7 @@ class OsConfigZonalServiceAsyncClient:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -453,6 +469,8 @@ class OsConfigZonalServiceAsyncClient:
                 print("Waiting for operation to complete...")
 
                 response = operation.result()
+
+                # Handle the response
                 print(response)
 
         Args:
@@ -563,7 +581,7 @@ class OsConfigZonalServiceAsyncClient:
         revision ID in the ``name`` parameter.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -579,7 +597,7 @@ class OsConfigZonalServiceAsyncClient:
                 # Make the request
                 response = client.get_os_policy_assignment(request=request)
 
-                # Handle response
+                # Handle the response
                 print(response)
 
         Args:
@@ -671,7 +689,7 @@ class OsConfigZonalServiceAsyncClient:
         returned.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -686,6 +704,8 @@ class OsConfigZonalServiceAsyncClient:
 
                 # Make the request
                 page_result = client.list_os_policy_assignments(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -771,7 +791,7 @@ class OsConfigZonalServiceAsyncClient:
         OS policy assignment.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -786,6 +806,8 @@ class OsConfigZonalServiceAsyncClient:
 
                 # Make the request
                 page_result = client.list_os_policy_assignment_revisions(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -884,7 +906,7 @@ class OsConfigZonalServiceAsyncClient:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -903,6 +925,8 @@ class OsConfigZonalServiceAsyncClient:
                 print("Waiting for operation to complete...")
 
                 response = operation.result()
+
+                # Handle the response
                 print(response)
 
         Args:
@@ -1001,7 +1025,7 @@ class OsConfigZonalServiceAsyncClient:
         Compute Engine VM instance.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1017,7 +1041,7 @@ class OsConfigZonalServiceAsyncClient:
                 # Make the request
                 response = client.get_instance_os_policies_compliance(request=request)
 
-                # Handle response
+                # Handle the response
                 print(response)
 
         Args:
@@ -1065,6 +1089,11 @@ class OsConfigZonalServiceAsyncClient:
                    compliance](\ https://cloud.google.com/compute/docs/os-configuration-management/view-compliance).
 
         """
+        warnings.warn(
+            "OsConfigZonalServiceAsyncClient.get_instance_os_policies_compliance is deprecated",
+            DeprecationWarning,
+        )
+
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
@@ -1120,7 +1149,7 @@ class OsConfigZonalServiceAsyncClient:
         Engine VM instances in the specified zone.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1135,6 +1164,8 @@ class OsConfigZonalServiceAsyncClient:
 
                 # Make the request
                 page_result = client.list_instance_os_policies_compliances(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -1170,6 +1201,11 @@ class OsConfigZonalServiceAsyncClient:
                 automatically.
 
         """
+        warnings.warn(
+            "OsConfigZonalServiceAsyncClient.list_instance_os_policies_compliances is deprecated",
+            DeprecationWarning,
+        )
+
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
@@ -1215,6 +1251,243 @@ class OsConfigZonalServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def get_os_policy_assignment_report(
+        self,
+        request: Union[
+            os_policy_assignment_reports.GetOSPolicyAssignmentReportRequest, dict
+        ] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> os_policy_assignment_reports.OSPolicyAssignmentReport:
+        r"""Get the OS policy asssignment report for the
+        specified Compute Engine VM instance.
+
+
+        .. code-block:: python
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_get_os_policy_assignment_report():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.GetOSPolicyAssignmentReportRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_os_policy_assignment_report(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentReportRequest, dict]):
+                The request object. Get a report of the OS policy
+                assignment for a VM instance.
+            name (:class:`str`):
+                Required. API resource name for OS policy assignment
+                report.
+
+                Format:
+                ``/projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}/report``
+
+                For ``{project}``, either ``project-number`` or
+                ``project-id`` can be provided. For ``{instance_id}``,
+                either Compute Engine ``instance-id`` or
+                ``instance-name`` can be provided. For
+                ``{assignment_id}``, the OSPolicyAssignment id must be
+                provided.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1alpha.types.OSPolicyAssignmentReport:
+                A report of the OS policy assignment
+                status for a given instance.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = os_policy_assignment_reports.GetOSPolicyAssignmentReportRequest(
+            request
+        )
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.get_os_policy_assignment_report,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
+    async def list_os_policy_assignment_reports(
+        self,
+        request: Union[
+            os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest, dict
+        ] = None,
+        *,
+        parent: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> pagers.ListOSPolicyAssignmentReportsAsyncPager:
+        r"""List OS policy asssignment reports for all Compute
+        Engine VM instances in the specified zone.
+
+
+        .. code-block:: python
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_list_os_policy_assignment_reports():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.ListOSPolicyAssignmentReportsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignment_reports(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentReportsRequest, dict]):
+                The request object. List the OS policy assignment
+                reports for VM instances.
+            parent (:class:`str`):
+                Required. The parent resource name.
+
+                Format:
+                ``projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}/reports``
+
+                For ``{project}``, either ``project-number`` or
+                ``project-id`` can be provided. For ``{instance}``,
+                either ``instance-name``, ``instance-id``, or ``-`` can
+                be provided. If '-' is provided, the response will
+                include OSPolicyAssignmentReports for all instances in
+                the project/location. For ``{assignment}``, either
+                ``assignment-id`` or ``-`` can be provided. If '-' is
+                provided, the response will include
+                OSPolicyAssignmentReports for all OSPolicyAssignments in
+                the project/location. Either {instance} or {assignment}
+                must be ``-``.
+
+                For example:
+                ``projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/-/reports``
+                returns all reports for the instance
+                ``projects/{project}/locations/{location}/instances/-/osPolicyAssignments/{assignment-id}/reports``
+                returns all the reports for the given assignment across
+                all instances.
+                ``projects/{project}/locations/{location}/instances/-/osPolicyAssignments/-/reports``
+                returns all the reports for all assignments across all
+                instances.
+
+                This corresponds to the ``parent`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1alpha.services.os_config_zonal_service.pagers.ListOSPolicyAssignmentReportsAsyncPager:
+                A response message for listing OS
+                Policy assignment reports including the
+                page of results and page token.
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(
+            request
+        )
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if parent is not None:
+            request.parent = parent
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.list_os_policy_assignment_reports,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__aiter__` convenience method.
+        response = pagers.ListOSPolicyAssignmentReportsAsyncPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def get_inventory(
         self,
         request: Union[inventory.GetInventoryRequest, dict] = None,
@@ -1228,7 +1501,7 @@ class OsConfigZonalServiceAsyncClient:
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1244,7 +1517,7 @@ class OsConfigZonalServiceAsyncClient:
                 # Make the request
                 response = client.get_inventory(request=request)
 
-                # Handle response
+                # Handle the response
                 print(response)
 
         Args:
@@ -1335,7 +1608,7 @@ class OsConfigZonalServiceAsyncClient:
         specified zone.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1350,6 +1623,8 @@ class OsConfigZonalServiceAsyncClient:
 
                 # Make the request
                 page_result = client.list_inventories(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -1361,12 +1636,10 @@ class OsConfigZonalServiceAsyncClient:
                 Required. The parent resource name.
 
                 Format:
-                ``projects/{project}/locations/{location}/instances/{instance}``
+                ``projects/{project}/locations/{location}/instances/-``
 
                 For ``{project}``, either ``project-number`` or
-                ``project-id`` can be provided. For ``{instance}``, only
-                hyphen or dash character is supported to list
-                inventories across VMs.
+                ``project-id`` can be provided.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1444,7 +1717,7 @@ class OsConfigZonalServiceAsyncClient:
         vulnerability reports associated with them.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1460,7 +1733,7 @@ class OsConfigZonalServiceAsyncClient:
                 # Make the request
                 response = client.get_vulnerability_report(request=request)
 
-                # Handle response
+                # Handle the response
                 print(response)
 
         Args:
@@ -1547,7 +1820,7 @@ class OsConfigZonalServiceAsyncClient:
         the specified zone.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1562,6 +1835,8 @@ class OsConfigZonalServiceAsyncClient:
 
                 # Make the request
                 page_result = client.list_vulnerability_reports(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -1574,12 +1849,10 @@ class OsConfigZonalServiceAsyncClient:
                 Required. The parent resource name.
 
                 Format:
-                ``projects/{project}/locations/{location}/instances/{instance}``
+                ``projects/{project}/locations/{location}/instances/-``
 
                 For ``{project}``, either ``project-number`` or
-                ``project-id`` can be provided. For ``{instance}``, only
-                ``-`` character is supported to list vulnerability
-                reports across VMs.
+                ``project-id`` can be provided.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
