@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@ import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
+import warnings
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -41,6 +42,7 @@ from google.cloud.osconfig_v1alpha.types import config_common
 from google.cloud.osconfig_v1alpha.types import instance_os_policies_compliance
 from google.cloud.osconfig_v1alpha.types import inventory
 from google.cloud.osconfig_v1alpha.types import os_policy
+from google.cloud.osconfig_v1alpha.types import os_policy_assignment_reports
 from google.cloud.osconfig_v1alpha.types import os_policy_assignments
 from google.cloud.osconfig_v1alpha.types import vulnerability
 from google.protobuf import empty_pb2  # type: ignore
@@ -209,6 +211,27 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def instance_os_policy_assignment_path(
+        project: str, location: str, instance: str, assignment: str,
+    ) -> str:
+        """Returns a fully-qualified instance_os_policy_assignment string."""
+        return "projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}".format(
+            project=project,
+            location=location,
+            instance=instance,
+            assignment=assignment,
+        )
+
+    @staticmethod
+    def parse_instance_os_policy_assignment_path(path: str) -> Dict[str, str]:
+        """Parses a instance_os_policy_assignment path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/instances/(?P<instance>.+?)/osPolicyAssignments/(?P<assignment>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def inventory_path(project: str, location: str, instance: str,) -> str:
         """Returns a fully-qualified inventory string."""
@@ -245,6 +268,27 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def os_policy_assignment_report_path(
+        project: str, location: str, instance: str, assignment: str,
+    ) -> str:
+        """Returns a fully-qualified os_policy_assignment_report string."""
+        return "projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}/report".format(
+            project=project,
+            location=location,
+            instance=instance,
+            assignment=assignment,
+        )
+
+    @staticmethod
+    def parse_os_policy_assignment_report_path(path: str) -> Dict[str, str]:
+        """Parses a os_policy_assignment_report path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/instances/(?P<instance>.+?)/osPolicyAssignments/(?P<assignment>.+?)/report$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def vulnerability_report_path(project: str, location: str, instance: str,) -> str:
         """Returns a fully-qualified vulnerability_report string."""
@@ -511,8 +555,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -541,6 +584,8 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 print("Waiting for operation to complete...")
 
                 response = operation.result()
+
+                # Handle the response
                 print(response)
 
         Args:
@@ -679,8 +724,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -707,6 +751,8 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 print("Waiting for operation to complete...")
 
                 response = operation.result()
+
+                # Handle the response
                 print(response)
 
         Args:
@@ -821,8 +867,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         revision ID in the ``name`` parameter.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -838,7 +883,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 # Make the request
                 response = client.get_os_policy_assignment(request=request)
 
-                # Handle response
+                # Handle the response
                 print(response)
 
         Args:
@@ -930,8 +975,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         returned.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -946,6 +990,8 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
                 # Make the request
                 page_result = client.list_os_policy_assignments(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -1035,8 +1081,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         OS policy assignment.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1051,6 +1096,8 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
                 # Make the request
                 page_result = client.list_os_policy_assignment_revisions(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -1155,8 +1202,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1175,6 +1221,8 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 print("Waiting for operation to complete...")
 
                 response = operation.result()
+
+                # Handle the response
                 print(response)
 
         Args:
@@ -1277,8 +1325,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         Compute Engine VM instance.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1294,7 +1341,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 # Make the request
                 response = client.get_instance_os_policies_compliance(request=request)
 
-                # Handle response
+                # Handle the response
                 print(response)
 
         Args:
@@ -1342,6 +1389,11 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                    compliance](\ https://cloud.google.com/compute/docs/os-configuration-management/view-compliance).
 
         """
+        warnings.warn(
+            "OsConfigZonalServiceClient.get_instance_os_policies_compliance is deprecated",
+            DeprecationWarning,
+        )
+
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
@@ -1402,8 +1454,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         Engine VM instances in the specified zone.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1418,6 +1469,8 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
                 # Make the request
                 page_result = client.list_instance_os_policies_compliances(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -1453,6 +1506,11 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 automatically.
 
         """
+        warnings.warn(
+            "OsConfigZonalServiceClient.list_instance_os_policies_compliances is deprecated",
+            DeprecationWarning,
+        )
+
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
@@ -1503,6 +1561,251 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         # Done; return the response.
         return response
 
+    def get_os_policy_assignment_report(
+        self,
+        request: Union[
+            os_policy_assignment_reports.GetOSPolicyAssignmentReportRequest, dict
+        ] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> os_policy_assignment_reports.OSPolicyAssignmentReport:
+        r"""Get the OS policy asssignment report for the
+        specified Compute Engine VM instance.
+
+
+        .. code-block:: python
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_get_os_policy_assignment_report():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.GetOSPolicyAssignmentReportRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_os_policy_assignment_report(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentReportRequest, dict]):
+                The request object. Get a report of the OS policy
+                assignment for a VM instance.
+            name (str):
+                Required. API resource name for OS policy assignment
+                report.
+
+                Format:
+                ``/projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}/report``
+
+                For ``{project}``, either ``project-number`` or
+                ``project-id`` can be provided. For ``{instance_id}``,
+                either Compute Engine ``instance-id`` or
+                ``instance-name`` can be provided. For
+                ``{assignment_id}``, the OSPolicyAssignment id must be
+                provided.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1alpha.types.OSPolicyAssignmentReport:
+                A report of the OS policy assignment
+                status for a given instance.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a os_policy_assignment_reports.GetOSPolicyAssignmentReportRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(
+            request, os_policy_assignment_reports.GetOSPolicyAssignmentReportRequest
+        ):
+            request = os_policy_assignment_reports.GetOSPolicyAssignmentReportRequest(
+                request
+            )
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if name is not None:
+                request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[
+            self._transport.get_os_policy_assignment_report
+        ]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
+    def list_os_policy_assignment_reports(
+        self,
+        request: Union[
+            os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest, dict
+        ] = None,
+        *,
+        parent: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> pagers.ListOSPolicyAssignmentReportsPager:
+        r"""List OS policy asssignment reports for all Compute
+        Engine VM instances in the specified zone.
+
+
+        .. code-block:: python
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_list_os_policy_assignment_reports():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.ListOSPolicyAssignmentReportsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignment_reports(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentReportsRequest, dict]):
+                The request object. List the OS policy assignment
+                reports for VM instances.
+            parent (str):
+                Required. The parent resource name.
+
+                Format:
+                ``projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/{assignment}/reports``
+
+                For ``{project}``, either ``project-number`` or
+                ``project-id`` can be provided. For ``{instance}``,
+                either ``instance-name``, ``instance-id``, or ``-`` can
+                be provided. If '-' is provided, the response will
+                include OSPolicyAssignmentReports for all instances in
+                the project/location. For ``{assignment}``, either
+                ``assignment-id`` or ``-`` can be provided. If '-' is
+                provided, the response will include
+                OSPolicyAssignmentReports for all OSPolicyAssignments in
+                the project/location. Either {instance} or {assignment}
+                must be ``-``.
+
+                For example:
+                ``projects/{project}/locations/{location}/instances/{instance}/osPolicyAssignments/-/reports``
+                returns all reports for the instance
+                ``projects/{project}/locations/{location}/instances/-/osPolicyAssignments/{assignment-id}/reports``
+                returns all the reports for the given assignment across
+                all instances.
+                ``projects/{project}/locations/{location}/instances/-/osPolicyAssignments/-/reports``
+                returns all the reports for all assignments across all
+                instances.
+
+                This corresponds to the ``parent`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1alpha.services.os_config_zonal_service.pagers.ListOSPolicyAssignmentReportsPager:
+                A response message for listing OS
+                Policy assignment reports including the
+                page of results and page token.
+                Iterating over this object will yield
+                results and resolve additional pages
+                automatically.
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(
+            request, os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest
+        ):
+            request = os_policy_assignment_reports.ListOSPolicyAssignmentReportsRequest(
+                request
+            )
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if parent is not None:
+                request.parent = parent
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[
+            self._transport.list_os_policy_assignment_reports
+        ]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
+        )
+
+        # Send the request.
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # This method is paged; wrap the response in a pager, which provides
+        # an `__iter__` convenience method.
+        response = pagers.ListOSPolicyAssignmentReportsPager(
+            method=rpc, request=request, response=response, metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     def get_inventory(
         self,
         request: Union[inventory.GetInventoryRequest, dict] = None,
@@ -1516,8 +1819,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1533,7 +1835,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 # Make the request
                 response = client.get_inventory(request=request)
 
-                # Handle response
+                # Handle the response
                 print(response)
 
         Args:
@@ -1624,8 +1926,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         specified zone.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1640,6 +1941,8 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
                 # Make the request
                 page_result = client.list_inventories(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -1651,12 +1954,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 Required. The parent resource name.
 
                 Format:
-                ``projects/{project}/locations/{location}/instances/{instance}``
+                ``projects/{project}/locations/{location}/instances/-``
 
                 For ``{project}``, either ``project-number`` or
-                ``project-id`` can be provided. For ``{instance}``, only
-                hyphen or dash character is supported to list
-                inventories across VMs.
+                ``project-id`` can be provided.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1734,8 +2035,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         vulnerability reports associated with them.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1751,7 +2051,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 # Make the request
                 response = client.get_vulnerability_report(request=request)
 
-                # Handle response
+                # Handle the response
                 print(response)
 
         Args:
@@ -1838,8 +2138,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         the specified zone.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import osconfig_v1alpha
 
@@ -1854,6 +2153,8 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
                 # Make the request
                 page_result = client.list_vulnerability_reports(request=request)
+
+                # Handle the response
                 for response in page_result:
                     print(response)
 
@@ -1866,12 +2167,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 Required. The parent resource name.
 
                 Format:
-                ``projects/{project}/locations/{location}/instances/{instance}``
+                ``projects/{project}/locations/{location}/instances/-``
 
                 For ``{project}``, either ``project-number`` or
-                ``project-id`` can be provided. For ``{instance}``, only
-                ``-`` character is supported to list vulnerability
-                reports across VMs.
+                ``project-id`` can be provided.
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
